@@ -21,7 +21,7 @@ def test_whole_page(page_name, monkeypatch):
             sys.stdout = io.StringIO()
             sys.stdout.buffer = types.SimpleNamespace()
             sys.stdout.buffer.write = lambda x: sys.stdout.write(x.decode("utf-8"))
-            tldr.output(f_original)
+            tldr.output(f_original, "both")
 
             sys.stdout.seek(0)
             tldr_output = sys.stdout.read().encode("utf-8")
@@ -39,7 +39,7 @@ def test_markdown_mode(page_name):
         sys.stdout = io.StringIO()
         sys.stdout.buffer = types.SimpleNamespace()
         sys.stdout.buffer.write = lambda x: sys.stdout.write(x.decode("utf-8"))
-        tldr.output(d_original.splitlines(), plain=True)
+        tldr.output(d_original.splitlines(), "both", plain=True)
 
         sys.stdout.seek(0)
         tldr_output = sys.stdout.read().encode("utf-8")
@@ -142,7 +142,7 @@ def test_get_commands(monkeypatch, tmp_path):
     Path.mkdir(cache_default, parents=True)
     Path.touch(cache_default / "lspci.md")
 
-    monkeypatch.setenv("HOME", tmp_path)
+    monkeypatch.setenv("HOME", str(tmp_path))
 
     result = tldr.get_commands(platforms=["linux"])
 
